@@ -93,9 +93,6 @@ gb_font_selection_dialog_new (GbWidgetNewData *data)
 			 data->action == GB_CREATING ? "font_selection" : NULL);
   gb_widget_set_child_name (fontsel->fontsel, GladeChildFontSelection);
 
-  gtk_object_set_data (GTK_OBJECT (new_widget), TypeHint,
-		       GINT_TO_POINTER (GLADE_TYPE_HINT_DIALOG_INDEX));
-
   return new_widget;
 }
 
@@ -185,20 +182,13 @@ gb_font_selection_dialog_write_source (GtkWidget * widget,
 				       GbWidgetWriteSourceData * data)
 {
   gchar *wname, *child_name;
-  gboolean translatable, context;
-  gchar *comments;
 
   if (data->create_widget)
     {
-      glade_util_get_translation_properties (widget, Title, &translatable,
-					     &comments, &context);
-      source_add_translator_comments (data, translatable, comments);
-
       source_add (data, "  %s = gtk_font_selection_dialog_new (%s);\n",
 		  data->wname,
-		  source_make_string_full (GTK_WINDOW (widget)->title,
-					   data->use_gettext && translatable,
-					   context));
+		  source_make_string (GTK_WINDOW (widget)->title,
+				      data->use_gettext));
     }
 
   gb_widget_write_standard_source (widget, data);
