@@ -21,7 +21,7 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkcheckmenuitem.h>
-#include <gtk/gtkfilechooserdialog.h>
+#include <gtk/gtkfilesel.h>
 #include <gtk/gtkhbbox.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkimagemenuitem.h>
@@ -49,8 +49,6 @@
 #include "editor.h"
 #include "gbwidget.h"
 #include "load.h"
-#include "property.h"
-#include "tree.h"
 #include "utils.h"
 
 /* This is used to store a pointer to a GladeProjectWindow in the main window.
@@ -87,7 +85,6 @@ static void glade_project_window_on_new_project_ok (GladeProjectWindow *project_
 static void glade_project_window_on_open_project (GtkWidget *widget,
 					       gpointer   data);
 static void glade_project_window_real_open_project (GtkWidget          *widget,
-						    gint		response_id,
 						    GladeProjectWindow *project_window);
 
 static void glade_project_window_drag_data_received (GtkWidget *widget,
@@ -113,7 +110,6 @@ static void glade_project_window_on_save_project_as (GtkWidget *widget,
 						     gpointer   data);
 static void glade_project_window_save_project_as (GladeProjectWindow *project_window);
 static void glade_project_window_save_as_callback (GtkWidget          *widget,
-						   gint		   response_id,
 						   GladeProjectWindow *project_window);
 #endif
 static gboolean glade_project_window_real_save_project (GladeProjectWindow *project_window,
@@ -227,7 +223,7 @@ static GnomeUIInfo FileMenu[] =
     0, 0, NULL
   },
   GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_MENU_QUIT_ITEM (glade_project_window_quit, NULL),
+  GNOMEUIINFO_MENU_EXIT_ITEM (glade_project_window_quit, NULL),
   GNOMEUIINFO_END
 };
 
@@ -446,9 +442,20 @@ glade_project_window_new (void)
 
   /* Set the states of the toggle items. */
   palette_item = ViewMenu[GLADE_PALETTE_ITEM].widget;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (palette_item),
+				  TRUE);
+
   property_editor_item = ViewMenu[GLADE_PROPERTY_EDITOR_ITEM].widget;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (property_editor_item),
+				  TRUE);
+
   widget_tree_item = ViewMenu[GLADE_WIDGET_TREE_ITEM].widget;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget_tree_item),
+				  FALSE);
+
   clipboard_item = ViewMenu[GLADE_CLIPBOARD_ITEM].widget;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (clipboard_item),
+				  FALSE);
 
   show_grid_item = SettingsMenu[GLADE_SHOW_GRID_ITEM].widget;
   gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (show_grid_item),
@@ -732,6 +739,8 @@ glade_project_window_new (void)
   gtk_tooltips_set_tip (tooltips, menuitem, _("Show the palette of widgets"),
 			NULL);
   palette_item = menuitem;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (palette_item),
+				  TRUE);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_check_menu_item_new_with_mnemonic (_("Show Property _Editor"));
@@ -742,6 +751,8 @@ glade_project_window_new (void)
   gtk_tooltips_set_tip (tooltips, menuitem,
 			_("Show the property editor"), NULL);
   property_editor_item = menuitem;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (property_editor_item),
+				  TRUE);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_check_menu_item_new_with_mnemonic (_("Show Widget _Tree"));
@@ -752,6 +763,8 @@ glade_project_window_new (void)
   gtk_tooltips_set_tip (tooltips, menuitem,
 			_("Show the widget tree"), NULL);
   widget_tree_item = menuitem;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (widget_tree_item),
+				  FALSE);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_check_menu_item_new_with_mnemonic (_("Show _Clipboard"));
@@ -762,6 +775,8 @@ glade_project_window_new (void)
   gtk_tooltips_set_tip (tooltips, menuitem,
 			_("Show the clipboard"), NULL);
   clipboard_item = menuitem;
+  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (clipboard_item),
+				  FALSE);
   gtk_widget_show (menuitem);
 
   menuitem = gtk_separator_menu_item_new ();
@@ -1102,54 +1117,44 @@ glade_project_window_on_open_project (GtkWidget *widget,
 {
   GladeProjectWindow *project_window;
   GtkWidget *filesel;
-  GtkFileFilter *filter;
 
   project_window = get_glade_project_window (widget);
   g_return_if_fail (project_window != NULL);
 
-  filesel = gtk_file_chooser_dialog_new (_("Open Project"),
-					 GTK_WINDOW (project_window->window),
-					 GTK_FILE_CHOOSER_ACTION_OPEN,
-					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					 GTK_STOCK_OPEN, GTK_RESPONSE_OK,
-					 NULL);
-  gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
+  filesel = gtk_file_selection_new (_("Open Project"));
   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
-
-  g_signal_connect (filesel, "response",
-		    GTK_SIGNAL_FUNC (glade_project_window_real_open_project),
-		    project_window);
-
-  filter = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filter, "Glade Files");
-  gtk_file_filter_add_pattern (filter, "*.glade");
-  gtk_file_filter_add_pattern (filter, "*.glade2");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
-
-  filter = gtk_file_filter_new ();
-  gtk_file_filter_set_name (filter, "All Files");
-  gtk_file_filter_add_pattern (filter, "*");
-  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (filesel), filter);
-
+  gtk_window_set_wmclass (GTK_WINDOW (filesel), "open_project", "Glade");  
+  if (GTK_IS_WINDOW (project_window->window))
+    gtk_window_set_transient_for (GTK_WINDOW (filesel),
+				  GTK_WINDOW (project_window->window));
   if (project_window->current_directory)
     glade_util_set_file_selection_filename (filesel, project_window->current_directory);
 
+  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
+		      "clicked",
+		      GTK_SIGNAL_FUNC (glade_project_window_real_open_project),
+		      project_window);
+  gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
+			     "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
+			     GTK_OBJECT (filesel));
+  gtk_signal_connect (GTK_OBJECT (filesel), "key_press_event",
+		      GTK_SIGNAL_FUNC (glade_util_check_key_is_esc),
+		      GINT_TO_POINTER (GladeEscDestroys));
   gtk_widget_show (filesel);
 }
 
 
 static void
-glade_project_window_real_open_project (GtkWidget          *filesel,
-					gint		    response_id,
+glade_project_window_real_open_project (GtkWidget          *widget,
 					GladeProjectWindow *project_window)
 {
-  if (response_id == GTK_RESPONSE_OK)
-    {
-      gchar *filename = glade_util_get_file_selection_filename (filesel);
-      if (filename)
-	glade_project_window_open_project (project_window, filename);
-      g_free (filename);
-    }
+  GtkWidget *filesel;
+  gchar *filename;
+
+  filesel = gtk_widget_get_toplevel (widget);
+  filename = glade_util_get_file_selection_filename (filesel);
+  glade_project_window_open_project (project_window, filename);
+  g_free (filename);
   gtk_widget_destroy (filesel);
 }
 
@@ -1472,51 +1477,51 @@ glade_project_window_save_project_as (GladeProjectWindow *project_window)
 {
   GtkWidget *filesel;
 
-  filesel = gtk_file_chooser_dialog_new (_("Save Project"),
-					 GTK_WINDOW (project_window->window),
-					 GTK_FILE_CHOOSER_ACTION_SAVE,
-					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					 GTK_STOCK_SAVE, GTK_RESPONSE_OK,
-					 NULL);
-  gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
+  filesel = gtk_file_selection_new (_("Save Project"));
   gtk_window_set_position (GTK_WINDOW (filesel), GTK_WIN_POS_MOUSE);
- 
-  g_signal_connect (options->filesel, "response",
-		    GTK_SIGNAL_FUNC (glade_project_window_save_as_callback),
-		    project_window);
-
+  gtk_window_set_wmclass (GTK_WINDOW (filesel), "save_project", "Glade");  
+  if (GTK_IS_WINDOW (project_window->window))
+    gtk_window_set_transient_for (GTK_WINDOW (filesel),
+				  GTK_WINDOW (project_window->window));
   if (project_window->current_directory)
     glade_util_set_file_selection_filename (filesel, project_window->current_directory);
-
+  gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->ok_button),
+		      "clicked",
+		      GTK_SIGNAL_FUNC (glade_project_window_save_as_callback),
+		      project_window);
+  gtk_signal_connect_object (GTK_OBJECT (GTK_FILE_SELECTION (filesel)->cancel_button),
+			     "clicked", GTK_SIGNAL_FUNC (gtk_widget_destroy),
+			     GTK_OBJECT (filesel));
+  gtk_signal_connect (GTK_OBJECT (filesel), "key_press_event",
+		      GTK_SIGNAL_FUNC (glade_util_check_key_is_esc),
+		      GINT_TO_POINTER (GladeEscDestroys));
   gtk_widget_show (filesel);
 }
 
 
 static void
-glade_project_window_save_as_callback (GtkWidget          *filesel,
-				       gint		   response_id,
+glade_project_window_save_as_callback (GtkWidget          *widget,
 				       GladeProjectWindow *project_window)
 {
   GladeProject *project;
+  GtkWidget *filesel;
   gchar *filename;
+  gboolean saved;
 
-  if (response_id == GTK_RESPONSE_OK)
+  filesel = gtk_widget_get_toplevel (widget);
+  filename = glade_util_get_file_selection_filename (filesel);
+
+  g_free (project_window->current_directory);
+  project_window->current_directory = glade_util_dirname (filename);
+
+  project = glade_project_view_get_project (GLADE_PROJECT_VIEW (project_window->project_view));
+  if (project)
     {
-      filename = glade_util_get_file_selection_filename (filesel);
-
-      g_free (project_window->current_directory);
-      project_window->current_directory = glade_util_dirname (filename);
-
-      project = glade_project_view_get_project (GLADE_PROJECT_VIEW (project_window->project_view));
-      if (project)
-	{
-	  glade_project_set_xml_filename (project, filename);
-	  glade_project_window_real_save_project (project_window, TRUE);
-	}
-      g_free (filename);
+      glade_project_set_xml_filename (project, filename);
+      glade_project_window_real_save_project (project_window, TRUE);
     }
-
   gtk_widget_destroy (filesel);
+  g_free (filename);
 }
 #endif
 
@@ -1705,11 +1710,7 @@ glade_project_window_show_quit_dialog (GladeProjectWindow *project_window)
   gtk_window_set_wmclass (GTK_WINDOW (dialog), "quit", "Glade");
 
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
-    {
-      glade_save_settings (project_window, glade_palette, win_property,
-			   win_tree, glade_clipboard);
-      gtk_widget_destroy (project_window->window);
-    }
+    gtk_widget_destroy (project_window->window);
 
   gtk_widget_destroy (dialog);
 }
@@ -1796,23 +1797,6 @@ glade_project_window_real_delete (GladeProjectWindow *project_window)
 }
 
 
-static void
-refresh_menu_item (GtkWidget *menuitem, GtkWidget *window)
-{
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem),
-				  GTK_WIDGET_VISIBLE (window));
-}
-
-void
-glade_project_window_refresh_menu_items (void)
-{
-  refresh_menu_item (palette_item, glade_palette);
-  refresh_menu_item (property_editor_item, win_property);
-  refresh_menu_item (widget_tree_item, win_tree);
-  refresh_menu_item (clipboard_item, glade_clipboard);
-}
-
-
 void
 glade_project_window_uncheck_palette_menu_item (void)
 {
